@@ -1,5 +1,5 @@
 package Log::Contextual::Role::Router;
-$Log::Contextual::Role::Router::VERSION = '0.006001';
+$Log::Contextual::Role::Router::VERSION = '0.006002';
 # ABSTRACT: Abstract interface between loggers and logging code blocks
 
 use Moo::Role;
@@ -12,6 +12,18 @@ requires 'handle_log_request';
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Log::Contextual::Role::Router - Abstract interface between loggers and logging code blocks
+
+=head1 VERSION
+
+version 0.006002
+
 =head1 SYNOPSIS
 
   package MyApp::Log::Router;
@@ -180,3 +192,16 @@ as well.
 =back
 
 =back
+
+=head1 AUTHOR
+
+Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
