@@ -1,5 +1,5 @@
 package Log::Contextual::Router;
-$Log::Contextual::Router::VERSION = '0.006001';
+$Log::Contextual::Router::VERSION = '0.006002';
 use Moo;
 use Scalar::Util 'blessed';
 
@@ -141,3 +141,29 @@ sub handle_log_request {
 
 1;
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Log::Contextual::Router
+
+=head1 VERSION
+
+version 0.006002
+
+=head1 AUTHOR
+
+Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
