@@ -1,5 +1,5 @@
 package Log::Contextual::WarnLogger;
-$Log::Contextual::WarnLogger::VERSION = '0.006001';
+$Log::Contextual::WarnLogger::VERSION = '0.006002';
 # ABSTRACT: logger for libraries using Log::Contextual
 
 use strict;
@@ -119,6 +119,18 @@ sub _log {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Log::Contextual::WarnLogger - logger for libraries using Log::Contextual
+
+=head1 VERSION
+
+version 0.006002
+
 =head1 SYNOPSIS
 
  package My::Package;
@@ -137,8 +149,6 @@ __END__
    ...
  }
 
-
-
 =head1 DESCRIPTION
 
 This module is a simple logger made for libraries using L<Log::Contextual>.  We
@@ -271,5 +281,15 @@ environment variable is enabled.
 If different levels are specified, appropriate is_$level functions work as you
 would expect.
 
-=cut
+=head1 AUTHOR
 
+Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
